--------------------------------------------------------
--  DDL for Package ASSERTS
--------------------------------------------------------

  CREATE OR REPLACE PACKAGE "REGALS"."ASSERTS" as
 
    -- raise an error given a procedure and a message
    procedure raiseError(proc in varchar2, message in varchar2);
 
    -- assert a condition
    procedure assert(
        condition in boolean,
        proc in varchar2,
        message in varchar2);
 
    -- assert that given values are equal
    procedure assertEquals(
        expected in varchar2,
        actual in varchar2,
        proc in varchar2);
 
end asserts;

/


--------------------------------------------------------
--  DDL for Package Body ASSERTS
--------------------------------------------------------

  CREATE OR REPLACE PACKAGE BODY "REGALS"."ASSERTS" as
 
    -- raise an error given a procedure and a message
    procedure raiseError(proc in varchar2, message in varchar2) is
    begin
        raise_application_error(-20000, 'Error in ' || proc || ': ' || message);
    end raiseerror;
 
    -- assert a condition
    procedure assert(
        condition in boolean,
        proc in varchar2,
        message in varchar2) is
    begin
        if not condition then
            raiseError(proc, message);
        end if;
    end assert;
 
    -- assert that given values are equal
    procedure assertEquals(
        expected in varchar2,
        actual in varchar2,
        proc in varchar2) is
    begin
        if not expected = actual then
           -- raiseError(proc, 'expected ' || expected || ', got ' || actual);
            dbms_output.put_line('ERROR:  '|| proc || ' expected ' || expected || ' , got ' || actual ); 
         else
            dbms_output.put_line('OK:  '|| proc || ' expected ' || expected || ' , got ' || actual );           
        end if;
    end assertEquals;
 
end asserts;

/


--------------------------------------------------------
--  DDL for Package MYTEST
--------------------------------------------------------

  CREATE OR REPLACE PACKAGE "REGALS"."MYTEST" as
    
    procedure testAddRegalEvent;
     procedure testAddEvent;
    procedure testAddRegalDesitjat;
    procedure testAddParticipantsEvent;
     procedure testAddTransaccions_regals;
    procedure testError_01RegalDesitjat;
    procedure  testError_02RegalDesitjat;
    procedure testError_03RegalDesitjat;
    procedure testError_04RegalDesitjat;
    procedure  testError_05RegalDesitjat;
    procedure testError_01ParticipantsEvent;
     procedure testError_03ParticipantsEvent;
      procedure testError_02ParticipantsEvent;
      procedure testError_01Event;
       procedure testError_02Event;
       procedure testError_03Event;
        procedure testError_04Event;
       procedure testError_01TransaccionsRegals; 
       procedure testErro_02TransaccionsRegals;
       procedure testError_03TransaccionsRegals ;
        procedure testError_04TransaccionsRegals;
    procedure testError_01AddEvent;
    procedure testBaixa_tots_processos;
     procedure testModificacioRegalDesitjat;
     procedure testError_01ModRegalDesitjat;
     -- procedure testError_02ModRegalDesitjat;
  
    
    -- run all tests
    procedure runAllTests;
end MyTest;

/


--------------------------------------------------------
--  DDL for Package Body MYTEST
--------------------------------------------------------

  CREATE OR REPLACE PACKAGE BODY "REGALS"."MYTEST" as
  ---------------------------------------TOTS ELS ERROR I OK DEL PROCEDIMENT ADD_REGAL_DESITJAT------------------------------------------------------------ 
    -- el resultat s'espera un ok
     procedure testAddRegalDesitjat as
      v_rsp varchar2(80);
    begin
   ADD_REGALS_DESITJATS(61,'1','1','6','test',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp, 'OK', 'MyTest.testAddRegalEvent');
     rollback;
    end;
  -------------------------------------------------------------------------  
  
    
    -- el resultat s'espera ERROR ADD_RE_DESIT_01(data no correcte)
    procedure testError_01RegalDesitjat as
      v_rsp varchar2(80);
    begin
   ADD_REGALS_DESITJATS(61,'1','1','6','test','12-06-2014',v_rsp);
    
     asserts.assertEquals(v_rsp,'ERROR ADD_RE_DESIT_01: ', 'MyTest.error_01RegalDesitjat');
     rollback;
    end;
   
  -----------------------------------------------------------------------
  
  
   -- el resultat s'espera ERROR ADD_RE_DESIT_02(id usuari inexistent)
    procedure testError_02RegalDesitjat as
      v_rsp varchar2(80);
    begin
   ADD_REGALS_DESITJATS(500,'1','1','6','test',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp,'ERROR ADD_RE_DESIT_02: ', 'MyTest.error_02RegalDesitjat');
     rollback;
    end;
   
  ------------------------------------------------------------------------ 
  
  
  
  
  -- el resultat s'espera ERROR ADD_RE_DESIT_02(codi_proveidor inexistent)
    procedure testError_03RegalDesitjat as
      v_rsp varchar2(80);
    begin
   ADD_REGALS_DESITJATS(1,'600','1','6','test',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp,'ERROR ADD_RE_DESIT_02: ', ' Mytest.testError_03RegalDesitjat');
     rollback;
    end;
   
  ------------------------------------------------------------------------ 
  
   -- el resultat s'espera ERROR ADD_RE_DESIT_02(referncia cataleg inexistent)
    procedure testError_04RegalDesitjat as
      v_rsp varchar2(80);
    begin
   ADD_REGALS_DESITJATS(1,'1','10','6','test',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp,'ERROR ADD_RE_DESIT_02: ', 'Mytest.error_04RegalDesitjat');
     rollback;
    end;
   
  ------------------------------------------------------------------------ 
  
   -- el resultat s'espera ERROR ADD_RE_DESIT_02(article inexistent)
    procedure testError_05RegalDesitjat as
      v_rsp varchar2(80);
    begin
   ADD_REGALS_DESITJATS(1,'1','1','40','test',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp,'ERROR ADD_RE_DESIT_02: ', 'Mytest.error_05RegalDesitjat');
     rollback;
    end;
   
  ------------------------------------------------------------------------ 
  
  
  
  --------------------------------------TOTS ELS ERROR I OK DEL PROCEDIMENT ADD_regal_event-----------------------------------------------------------------------------------------------
  
    procedure testAddRegalEvent as
        v_rsp varchar2(80);
    begin
        -- insertem un event correctament la sortida te que ser ok 
      ADD_REGAL_EVENT(242,179,21,10, v_rsp);
      asserts.assertEquals(v_rsp, 'OK', 'MyTest.testAddEvent');
      rollback;
    end;
  
 
  -------------- -- el resultat s'espera ERROR ADD_RE_EV_01(usuarid'entrega inexistent)----------------------Corregir
  
      procedure testError_01AddEvent  as
      v_rsp varchar2(80);
        begin
     ADD_REGAL_EVENT(242,179,21,500, v_rsp);
    
      asserts.assertEquals(v_rsp,' ERROR ADD_RE_EV_01: ', 'Mytest.error_05RegalDesitjat');
     rollback;
    end;
   
    
    
    ------------------------------------TOTS ELS ERROR I OK DEL PROCEDIMENT  ADD_PARTICIPANTS_EVENT-------------------------------------------
    
     -- el resultat s'espera un ok
     procedure testAddParticipantsEvent as
      v_rsp varchar2(80);
    begin
   ADD_PARTICIPANTS_EVENT('241','11',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp, 'OK', 'MyTest.testAddParticipantsEvent');
     rollback;
    end;
  -------------------------------------------------------------------------  
     -------------- -- el resultat s'espera ERROR ADD_PAR_EV_03(ID_EVENT inexistent)----------------------
     procedure testError_03ParticipantsEvent as
      v_rsp varchar2(80);
    begin
   ADD_PARTICIPANTS_EVENT('500','11',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_PAR_EV_03: ', 'MyTest.error03ParticipantsEvent');
     rollback;
    end;
    
     -------------- -- el resultat s'espera ERROR ADD_PAR_EV_03(ID_EVENT inexistent)----------------------
     procedure testError_01ParticipantsEvent as
      v_rsp varchar2(80);
    begin
   ADD_PARTICIPANTS_EVENT('241','700',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_PAR_EV_03: ', 'MyTest.error01ParticipantsEvent');
     rollback;
    end;
  ---------------------------------el resultat s'espera  ERROR ADD_PAR_EV_02( data no actual)------------------------------------------------------
   procedure testError_02ParticipantsEvent as
      v_rsp varchar2(80);
    begin
   ADD_PARTICIPANTS_EVENT('241','11','12-04-2014',v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_PAR_EV_02: ', 'MyTest.error02ParticipantsEvent');
     rollback;
    end;
  
   ------------------------------------TOTS ELS ERROR I OK DEL PROCEDIMENT  ADD_EVENT-------------------------------------------
   
     -- el resultat s'espera un ok
     procedure testAddEvent as
      v_rsp varchar2(80);
    begin
   ADD_EVENT(sysdate,'3','9','2-10-2014',null,v_rsp);
    
     asserts.assertEquals(v_rsp, 'OK', 'MyTest.testAddEvent');
     rollback;
    end;
    
    -----------------------------------------------------------
    
     -------------- -- el resultat s'espera ERROR ADD_EVENT_01:(ID_EVENT inexistent)----------------------
     procedure testError_01Event as
      v_rsp varchar2(80);
    begin
    ADD_EVENT('08-04-2014','3','9','2-10-2014',null,v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_EVENT_01: ', 'MyTest.error01Event');
     rollback;
    end;
    
      -------------- -- el resultat s'esperaERROR ADD_EVENT_02:(data d'entrega incorrecta)----------------------
     procedure testError_02Event as
      v_rsp varchar2(80);
    begin
    ADD_EVENT(sysdate,'3','9','2-04-2014',null,v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_EVENT_02: ', 'MyTest.error02Event');
     rollback;
    end;
    
     -------------- -- el resultat s'esperaERROR ADD_EVENT_03:(ID_EVENT inexistent)----------------------
     procedure testError_03Event as
      v_rsp varchar2(80);
    begin
    ADD_EVENT(sysdate,'200','9','2-10-2014',null,v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_EVENT_03: ', 'MyTest.error03Event');
     rollback;
    end;
    
   -------------- -- el resultat s'espera ERROR ADD_EVENT_04:(algun camp buit)----------------------
     procedure testError_04Event as
      v_rsp varchar2(80);
    begin
    ADD_EVENT(null,null,null,null,null,v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_EVENT_04: ', 'MyTest.error04Event');
     rollback;
    end;
    
    
     ------------------------------------TOTS ELS ERROR I OK DEL PROCEDIMENT  ADD_TRANSACCIONS_REGALS-------------------------------------------
       -- el resultat s'espera un ok
     procedure testAddTransaccions_regals as
      v_rsp varchar2(80);
    begin
    ADD_TRANSACCIONS_REGALS(sysdate,'14',482,'1',5,v_rsp);
    
     asserts.assertEquals(v_rsp, 'OK', 'MyTest.testAddTransaccions_regals');
     rollback;
    end;
    
    -----------------------------------------------------------
    ---------------------------------el resultat s'espera ERROR ADD_TRANS_RE_01:( data no actual)------------------------------------------------------
   procedure testError_01TransaccionsRegals as
      v_rsp varchar2(80);
    begin
    ADD_TRANSACCIONS_REGALS('2-03-2014','14',482,'1',5,v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_TRANS_RE_01: ', 'MyTest.error01Transaccions_regals');
     rollback;
    end;
     ---------------------------------el resultat s'espera ERROR ADD_TRANS_RE_02:( camps que no existeixen)------------------------------------------------------
   procedure testErro_02TransaccionsRegals as
      v_rsp varchar2(80);
    begin
    ADD_TRANSACCIONS_REGALS(sysdate,'14',800,'1',5,v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_TRANS_RE_02: ', 'MyTest.error02Transaccions_regals');
     rollback;
    end;
    ---------------------------------------el resultat s'espera ERROR ADD_TRANS_RE_03:( camps nulls)------------------------------------------------------------------
     procedure testError_03TransaccionsRegals as
      v_rsp varchar2(80);
    begin
    ADD_TRANSACCIONS_REGALS(sysdate,'14',null,'1',5,v_rsp);
    
     asserts.assertEquals(v_rsp, 'ERROR ADD_TRANS_RE_03: ', 'MyTest.error03Transaccions_regals');
     rollback;
    end;
    --------------------------------------el resultat s'espera'Error ADD_DEVOLUCIO ' importTotal( devolucio)
     procedure testError_04TransaccionsRegals as
      v_rsp varchar2(80);
    begin
    ADD_TRANSACCIONS_REGALS(sysdate,'14',482,'1',100,v_rsp);
    
     asserts.assertEquals(v_rsp, 'Error ADD_DEVOLUCIO -87 ', 'MyTest.error04Transaccions_regals');
     rollback;
    end;
    
    ------------------------------------------------------baixes procediments----------------------------------------------------------------------------------------
    
     -- el resultat s'espera un ok
     procedure testBaixa_tots_processos as
      v_rsp varchar2(80);
      v_rsp1 varchar2(80);
    begin
      Baixa_Transaccions_regals(531,v_rsp);
      asserts.assertEquals(v_rsp, 'OK', 'MyTest.testBaixaTransaccions_regals');
     Baixa_Regal_Event(485,v_rsp);
     asserts.assertEquals(v_rsp, 'OK', 'MyTest.testBaixaRegal_Event');
     BAIXA_PARTICIPANTS_EVENT(282,11,v_rsp);
      asserts.assertEquals(v_rsp, 'OK', 'MyTest.testBaixa_participants_Event');
      Baixa_Event(282,v_rsp);
      asserts.assertEquals(v_rsp, 'OK', 'MyTest.testBaixa_Event');
       
      
     rollback;
    end;
    
    -----------------------------------------------------------
     ------------------------------------------------------modificacions procediments----------------------------------------------------------------------------------------
     -- el resultat s'espera un ok
     procedure testModificacioRegalDesitjat as
      v_rsp varchar2(80);
    begin
   MODIFICACIO_REGAL_DESITJAT(61,'1','1','6','test2',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp, 'OK', 'MyTest.testModifiRegalDesitjat');
     rollback;
    end;
  -----------------------------el resultat s'espera ERROR MOD_RE_DESIT_01:(data incorrecte)--------------------------------------------  
   procedure testError_01ModRegalDesitjat as
      v_rsp varchar2(80);
    begin
   MODIFICACIO_REGAL_DESITJAT(61,'1','1','6','test2','12-04-2014',v_rsp);
    
     asserts.assertEquals(v_rsp,'ERROR MOD_RE_DESIT_01: ','MyTest.testError_01ModRegalDesitjat');
     rollback;
    end;
  ------------------------------el resultat s'espera ERROR MOD_RE_DESIT_02:(hi ha algun valor que no existeix)-------------------------------------------  
  /* procedure testError_02ModRegalDesitjat as
      v_rsp varchar2(80);
    begin
   MODIFICACIO_REGAL_DESITJAT(61,'1','1','800','test2',sysdate,v_rsp);
    
     asserts.assertEquals(v_rsp,'ERROR MOD_RE_DESIT_02: ','MyTest.testError_02ModRegalDesitjat');
     rollback;
    end;
  -------------------------------------------------------------------------  
  */ 
  
  
  
    
    -- run all tests
    
    procedure runAllTests as 
    begin
     dbms_output.put_line(' TOTS EL ADD I ELS SEUS ERRORS DE CADA PROCEDIMENT    ');
      testAddRegalEvent;
       dbms_output.put_line('     ');
       testAddRegalDesitjat;
        dbms_output.put_line('     ');
       testAddParticipantsEvent;
        dbms_output.put_line('     ');
        testAddEvent;
          dbms_output.put_line('     ');
           testAddTransaccions_regals;
           dbms_output.put_line('     ');
        testError_01AddEvent;
         dbms_output.put_line('     ');
        testError_01RegalDesitjat;
         testError_02RegalDesitjat;
        testError_03RegalDesitjat;
         testError_04RegalDesitjat;
         testError_05RegalDesitjat;
          dbms_output.put_line('     ');
         testError_03ParticipantsEvent;
         testError_01ParticipantsEvent;
         testError_02ParticipantsEvent;
          dbms_output.put_line('     ');
           testError_01Event;
           testError_02Event;
           testError_03Event;
           testError_04Event;
           dbms_output.put_line('     ');
           testError_01TransaccionsRegals;
           testErro_02TransaccionsRegals;
           testError_03TransaccionsRegals;
           testError_04TransaccionsRegals;
             dbms_output.put_line('     ');
 dbms_output.put_line('BAIXES PROCEDIMENTS     ');
         testBaixa_tots_processos;
         dbms_output.put_line('     ');
          dbms_output.put_line('MODIFICACIONS PROCEDIMENTS    ');
         testModificacioRegalDesitjat;
          testError_01ModRegalDesitjat;
         -- testError_02ModRegalDesitjat;
           dbms_output.put_line('     ');
          
    end;
    
end MyTest;

/

